@@ -7,7 +7,7 @@ use SVG;
 use SVG::Sparkline::Utils;
 
 use 5.008000;
-our $VERSION = '0.2.5';
+our $VERSION = '0.2.6';
 
 # aliases to make calling shorter.
 *_f = *SVG::Sparkline::Utils::format_f;
@@ -19,34 +19,20 @@ sub make
     SVG::Sparkline::Utils::validate_array_param( $args, 'values' );
     my $valdesc = SVG::Sparkline::Utils::summarize_xy_values( $args->{values} );
 
-    my $dwidth;
-    if( $args->{width} )
-    {
-        $dwidth = $args->{width} - 2*$args->{padx};
-    }
-    else
-    {
-        $args->{width} = @{$valdesc->{vals}}+2*$args->{padx};
-        $dwidth = @{$valdesc->{vals}}
-    }
-    my $height = $args->{height} - 2*$args->{pady};
-    my $xscale = ($dwidth-1) / $valdesc->{xrange};
-    my $yscale = -$height / $valdesc->{yrange};
-    my $baseline = _f(-$yscale*$valdesc->{offset});
-
-    $args->{yoff} = -($baseline+$height+$args->{pady});
+    SVG::Sparkline::Utils::calculate_xscale( $args, $valdesc->{xrange} );
+    SVG::Sparkline::Utils::calculate_yscale_and_offset( $args, $valdesc->{yrange}, $valdesc->{offset} );
     my $svg = SVG::Sparkline::Utils::make_svg( $args );
 
-    my $points = join( ' ', "0,0",
-        ( map { _f($xscale*$_->[0]) .','. _f($yscale*$_->[1]) } @{$valdesc->{vals}} ),
-        _f($xscale * $valdesc->{vals}->[-1]->[0]).",0"
+    my $points = SVG::Sparkline::Utils::xypairs_to_points_str(
+        [ [0,0], @{$valdesc->{vals}}, [$valdesc->{vals}->[-1]->[0],0] ],
+        $args->{xscale}, $args->{yscale}
     );
     $svg->polygon( fill=>$args->{color}, points=>$points, stroke=>'none' );
 
     if( exists $args->{mark} )
     {
         _make_marks( $svg,
-            xscale=>$xscale, yscale=>$yscale,
+            xscale=>$args->{xscale}, yscale=>$args->{yscale},
             values=>$valdesc->{vals}, mark=>$args->{mark}
         );
     }
